@@ -57,9 +57,9 @@ int		ev_view_get_page	(EvView     *view);
 /* Page size */
 void		ev_view_zoom_in		(EvView     *view);
 void		ev_view_zoom_out	(EvView     *view);
-void		ev_view_normal_size	(EvView     *view);
-void		ev_view_best_fit	(EvView     *view);
-void		ev_view_fit_width	(EvView     *view);
+void		ev_view_set_size        (EvView     *view,
+					 int         width,
+					 int         height);
 
 /* Find */
 void            ev_view_find_next       (EvView     *view);
@@ -69,6 +69,10 @@ void            ev_view_find_previous   (EvView     *view);
 const char     *ev_view_get_status      (EvView     *view);
 const char     *ev_view_get_find_status (EvView     *view);
 
+/* Cursor */
+void           ev_view_hide_cursor     (EvView     *view);
+void           ev_view_show_cursor     (EvView     *view);
+
 G_END_DECLS
 
 #endif /* __EV_VIEW_H__ */
